@@ -8,13 +8,14 @@ pub use self::r#type::*;
 
 use std::collections::HashMap;
 use std::convert::TryInto;
+use std::future::Future;
 use std::io;
 use std::sync::Arc;
 
 use tokio::io::{AsyncBufReadExt, AsyncWriteExt, BufReader};
 use tokio::net::tcp::OwnedWriteHalf;
 use tokio::net::{lookup_host, TcpStream, ToSocketAddrs};
-use tokio::sync::Mutex;
+use tokio::sync::{mpsc, oneshot, Mutex};
 
 use crate::command::Command;
 use crate::message::Message;
@@ -22,16 +23,11 @@ use crate::pushmessage::*;
 use crate::reply::*;
 use crate::word::Word;
 
-use futures::channel::oneshot;
-use futures::{channel::mpsc, Future};
-use futures_util::sink::SinkExt;
-
 struct ConnectionInternal {
     tag_counter: usize,
     reply_map: HashMap<Box<Word>, oneshot::Sender<Result<Reply, CloseReason>>>,
     awaiting_history: Option<(i64, Vec<Message>)>,
-    push_channel: mpsc::Sender<PushMessage>,
-    close_reason: Option<CloseReason>,
+    push_channel: Result<mpsc::Sender<PushMessage>, CloseReason>,
 }
 
 impl ConnectionInternal {
@@ -48,7 +44,12 @@ impl ConnectionInternal {
             Some(p) => p,
             None => return, // we can ignore this push
         };
-        self.push_channel.send(push).await.unwrap();
+        self.push_channel
+            .as_mut()
+            .unwrap()
+            .send(push)
+            .await
+            .unwrap();
     }
 
     async fn handle_reply(&mut self, message: String) {
@@ -122,8 +123,7 @@ impl Connection {
             tag_counter: 0,
             reply_map: HashMap::new(),
             awaiting_history: None,
-            push_channel: push_send,
-            close_reason: None,
+            push_channel: Ok(push_send),
         }));
 
         let conn = Self {
@@ -142,18 +142,14 @@ impl Connection {
                 let mut internal = internal.lock().await;
                 match res {
                     Err(e) => {
-                        internal.push_channel.close_channel();
-
                         let close_reason = CloseReason::Err(e.to_string());
-                        internal.close_reason = Some(close_reason.clone());
+                        internal.push_channel = Err(close_reason.clone());
                         break (internal, close_reason);
                     }
                     Ok(0) => {
                         // EOF
-                        internal.push_channel.close_channel();
-
                         let close_reason = CloseReason::EOF;
-                        internal.close_reason = Some(close_reason.clone());
+                        internal.push_channel = Err(close_reason.clone());
                         break (internal, close_reason);
                     }
                     Ok(_) => {
@@ -168,7 +164,8 @@ impl Connection {
             }
         });
 
-        conn.send_command(Command::Version("4".try_into().unwrap()))
+        let version: &Word = "4".try_into().unwrap();
+        conn.send(&Command::Version(version.into()))
             .await?
             .map_err(|e| {
                 let (kind, e) = match e {
@@ -182,9 +179,9 @@ impl Connection {
     }
 
     /// Send the given `command` to this `Connection`.
-    pub fn send_command<'a, 'b>(
+    pub fn send<'a, 'b>(
         &'a self,
-        command: Command<'b>,
+        command: &'b Command<'b>,
     ) -> impl Future<Output = tokio::io::Result<Result<Reply, CloseReason>>> + 'a {
         let command = command.to_string();
 
@@ -218,10 +215,14 @@ impl Connection {
 
     /// Gets the reason this `Connection` is closed, or `None` if the `Connection` is still open.
     pub async fn close_reason(&self) -> Option<CloseReason> {
-        self.internal.lock().await.close_reason.clone()
+        let internal = self.internal.lock().await;
+        match &internal.push_channel {
+            Ok(_) => None,
+            Err(e) => Some(e.clone()),
+        }
     }
     /// Returns whether or not this `Connection` is closed.
     pub async fn is_closed(&self) -> bool {
-        self.internal.lock().await.close_reason.is_some()
+        self.internal.lock().await.push_channel.is_err()
     }
 }
