@@ -1,4 +1,4 @@
-use std::borrow::Borrow;
+use std::borrow::{Borrow, Cow};
 use std::convert::TryFrom;
 use std::fmt;
 use std::mem;
@@ -63,6 +63,17 @@ impl fmt::Display for Line {
     }
 }
 
+impl From<Box<Line>> for Cow<'_, Line> {
+    fn from(line: Box<Line>) -> Self {
+        Self::Owned(line)
+    }
+}
+impl<'a> From<&'a Line> for Cow<'a, Line> {
+    fn from(line: &'a Line) -> Self {
+        Self::Borrowed(line)
+    }
+}
+
 impl TryFrom<String> for Box<Line> {
     type Error = &'static str;
 
