@@ -1,4 +1,4 @@
-use std::borrow::Borrow;
+use std::borrow::{Borrow, Cow};
 use std::convert::TryFrom;
 use std::fmt;
 use std::mem;
@@ -63,6 +63,17 @@ impl fmt::Display for Word {
     }
 }
 
+impl From<Box<Word>> for Cow<'_, Word> {
+    fn from(word: Box<Word>) -> Self {
+        Self::Owned(word)
+    }
+}
+impl<'a> From<&'a Word> for Cow<'a, Word> {
+    fn from(word: &'a Word) -> Self {
+        Self::Borrowed(word)
+    }
+}
+
 impl TryFrom<String> for Box<Word> {
     type Error = &'static str;
 
